summaryrefslogtreecommitdiff
path: root/src/wx
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-06-11 23:50:59 +0100
committerCarl Hetherington <cth@carlh.net>2018-07-19 23:36:56 +0100
commitd7ac100c0eb1b5efdcfbec59be870fd869252840 (patch)
tree74643ed748e14ea25948c2f68ae2799ebae9d62b /src/wx
parent00ae2c28501bb757a6a45ba47ad4ecbe32412933 (diff)
Rename Subtitle -> Text
sed -i "s/SubtitleContent/TextContent/g" src/lib/*.cc src/lib/*.h src/wx/*.cc src/wx/*.h src/tools/*.cc test/*.cc sed -i "s/SubtitleDecoder/TextDecoder/g" src/lib/*.cc src/lib/*.h src/wx/*.cc src/wx/*.h src/tools/*.cc test/*.cc sed -i "s/subtitle_content/text_content/g" src/lib/*.cc src/lib/*.h src/wx/*.cc src/wx/*.h src/tools/*.cc test/*.cc src/lib/wscript src/wx/wscript sed -i "s/subtitle_decoder/text_decoder/g" src/lib/*.cc src/lib/*.h src/wx/*.cc src/wx/*.h src/tools/*.cc test/*.cc src/lib/wscript mv src/lib/subtitle_decoder.cc src/lib/text_decoder.cc mv src/lib/subtitle_decoder.h src/lib/text_decoder.h mv src/lib/subtitle_content.cc src/lib/text_content.cc mv src/lib/subtitle_content.h src/lib/text_content.h mv src/lib/dcp_subtitle_decoder.cc src/lib/dcp_text_decoder.cc mv src/lib/dcp_subtitle_decoder.h src/lib/dcp_text_decoder.h mv src/lib/dcp_subtitle_content.cc src/lib/dcp_text_content.cc mv src/lib/dcp_subtitle_content.h src/lib/dcp_text_content.h mv src/lib/text_subtitle_content.cc src/lib/text_text_content.cc mv src/lib/text_subtitle_content.h src/lib/text_text_content.h mv src/lib/text_subtitle_decoder.cc src/lib/text_text_decoder.cc mv src/lib/text_subtitle_decoder.h src/lib/text_text_decoder.h mv src/wx/timeline_subtitle_content_view.cc src/wx/timeline_text_content_view.cc mv src/wx/timeline_subtitle_content_view.h src/wx/timeline_text_content_view.h
Diffstat (limited to 'src/wx')
-rw-r--r--src/wx/content_panel.cc8
-rw-r--r--src/wx/dcp_panel.cc6
-rw-r--r--src/wx/fonts_dialog.cc2
-rw-r--r--src/wx/subtitle_appearance_dialog.cc4
-rw-r--r--src/wx/subtitle_panel.cc48
-rw-r--r--src/wx/subtitle_view.cc4
-rw-r--r--src/wx/timeline.cc8
-rw-r--r--src/wx/timeline_text_content_view.cc (renamed from src/wx/timeline_subtitle_content_view.cc)12
-rw-r--r--src/wx/timeline_text_content_view.h (renamed from src/wx/timeline_subtitle_content_view.h)10
-rw-r--r--src/wx/timing_panel.cc6
-rw-r--r--src/wx/wscript2
11 files changed, 55 insertions, 55 deletions
diff --git a/src/wx/content_panel.cc b/src/wx/content_panel.cc
index 4adeb90a4..2c0f35f6c 100644
--- a/src/wx/content_panel.cc
+++ b/src/wx/content_panel.cc
@@ -28,7 +28,7 @@
#include "image_sequence_dialog.h"
#include "film_viewer.h"
#include "lib/audio_content.h"
-#include "lib/subtitle_content.h"
+#include "lib/text_content.h"
#include "lib/video_content.h"
#include "lib/ffmpeg_content.h"
#include "lib/content_factory.h"
@@ -39,7 +39,7 @@
#include "lib/config.h"
#include "lib/log.h"
#include "lib/compose.hpp"
-#include "lib/text_subtitle_content.h"
+#include "lib/text_text_content.h"
#include "lib/text_subtitle.h"
#include <wx/wx.h>
#include <wx/notebook.h>
@@ -258,11 +258,11 @@ ContentPanel::selection_changed ()
BOOST_FOREACH (shared_ptr<Content> i, selected ()) {
DCPTime p;
p = i->position();
- if (dynamic_pointer_cast<TextSubtitleContent>(i) && i->paths_valid()) {
+ if (dynamic_pointer_cast<TextTextContent>(i) && i->paths_valid()) {
/* Rather special case; if we select a text subtitle file jump to its
first subtitle.
*/
- TextSubtitle ts (dynamic_pointer_cast<TextSubtitleContent>(i));
+ TextSubtitle ts (dynamic_pointer_cast<TextTextContent>(i));
if (ts.first()) {
p += DCPTime(ts.first().get(), _film->active_frame_rate_change(i->position()));
}
diff --git a/src/wx/dcp_panel.cc b/src/wx/dcp_panel.cc
index f2783af6b..5a380ec4e 100644
--- a/src/wx/dcp_panel.cc
+++ b/src/wx/dcp_panel.cc
@@ -32,7 +32,7 @@
#include "lib/ffmpeg_content.h"
#include "lib/audio_processor.h"
#include "lib/video_content.h"
-#include "lib/subtitle_content.h"
+#include "lib/text_content.h"
#include "lib/dcp_content.h"
#include "lib/audio_content.h"
#include <dcp/locale_convert.h>
@@ -433,8 +433,8 @@ void
DCPPanel::film_content_changed (int property)
{
if (property == AudioContentProperty::STREAMS ||
- property == SubtitleContentProperty::USE ||
- property == SubtitleContentProperty::BURN ||
+ property == TextContentProperty::USE ||
+ property == TextContentProperty::BURN ||
property == VideoContentProperty::SCALE ||
property == DCPContentProperty::REFERENCE_VIDEO ||
property == DCPContentProperty::REFERENCE_AUDIO ||
diff --git a/src/wx/fonts_dialog.cc b/src/wx/fonts_dialog.cc
index c85d18e34..c295ec327 100644
--- a/src/wx/fonts_dialog.cc
+++ b/src/wx/fonts_dialog.cc
@@ -24,7 +24,7 @@
#include "font_files_dialog.h"
#include "lib/font.h"
#include "lib/content.h"
-#include "lib/subtitle_content.h"
+#include "lib/text_content.h"
#include <wx/wx.h>
#include <boost/foreach.hpp>
#include <iostream>
diff --git a/src/wx/subtitle_appearance_dialog.cc b/src/wx/subtitle_appearance_dialog.cc
index 8ae479746..f78ed9ab5 100644
--- a/src/wx/subtitle_appearance_dialog.cc
+++ b/src/wx/subtitle_appearance_dialog.cc
@@ -20,8 +20,8 @@
#include "subtitle_appearance_dialog.h"
#include "rgba_colour_picker.h"
-#include "lib/text_subtitle_content.h"
-#include "lib/subtitle_content.h"
+#include "lib/text_text_content.h"
+#include "lib/text_content.h"
#include "lib/ffmpeg_subtitle_stream.h"
#include "lib/ffmpeg_content.h"
#include <wx/wx.h>
diff --git a/src/wx/subtitle_panel.cc b/src/wx/subtitle_panel.cc
index 1a42c1f57..da7891ca8 100644
--- a/src/wx/subtitle_panel.cc
+++ b/src/wx/subtitle_panel.cc
@@ -26,13 +26,13 @@
#include "fonts_dialog.h"
#include "subtitle_appearance_dialog.h"
#include "lib/ffmpeg_content.h"
-#include "lib/text_subtitle_content.h"
+#include "lib/text_text_content.h"
#include "lib/ffmpeg_subtitle_stream.h"
-#include "lib/dcp_subtitle_content.h"
-#include "lib/text_subtitle_decoder.h"
-#include "lib/dcp_subtitle_decoder.h"
+#include "lib/dcp_text_content.h"
+#include "lib/text_text_decoder.h"
+#include "lib/dcp_text_decoder.h"
#include "lib/dcp_content.h"
-#include "lib/subtitle_content.h"
+#include "lib/text_content.h"
#include "lib/decoder_factory.h"
#include <wx/spinctrl.h>
#include <boost/foreach.hpp>
@@ -209,22 +209,22 @@ SubtitlePanel::film_content_changed (int property)
}
}
setup_sensitivity ();
- } else if (property == SubtitleContentProperty::USE) {
+ } else if (property == TextContentProperty::USE) {
checked_set (_use, scs ? scs->subtitle->use() : false);
setup_sensitivity ();
- } else if (property == SubtitleContentProperty::BURN) {
+ } else if (property == TextContentProperty::BURN) {
checked_set (_burn, scs ? scs->subtitle->burn() : false);
- } else if (property == SubtitleContentProperty::X_OFFSET) {
+ } else if (property == TextContentProperty::X_OFFSET) {
checked_set (_x_offset, scs ? lrint (scs->subtitle->x_offset() * 100) : 0);
- } else if (property == SubtitleContentProperty::Y_OFFSET) {
+ } else if (property == TextContentProperty::Y_OFFSET) {
checked_set (_y_offset, scs ? lrint (scs->subtitle->y_offset() * 100) : 0);
- } else if (property == SubtitleContentProperty::X_SCALE) {
+ } else if (property == TextContentProperty::X_SCALE) {
checked_set (_x_scale, scs ? lrint (scs->subtitle->x_scale() * 100) : 100);
- } else if (property == SubtitleContentProperty::Y_SCALE) {
+ } else if (property == TextContentProperty::Y_SCALE) {
checked_set (_y_scale, scs ? lrint (scs->subtitle->y_scale() * 100) : 100);
- } else if (property == SubtitleContentProperty::LINE_SPACING) {
+ } else if (property == TextContentProperty::LINE_SPACING) {
checked_set (_line_spacing, scs ? lrint (scs->subtitle->line_spacing() * 100) : 100);
- } else if (property == SubtitleContentProperty::LANGUAGE) {
+ } else if (property == TextContentProperty::LANGUAGE) {
checked_set (_language, scs ? scs->subtitle->language() : "");
} else if (property == DCPContentProperty::REFERENCE_SUBTITLE) {
if (scs) {
@@ -265,9 +265,9 @@ SubtitlePanel::setup_sensitivity ()
BOOST_FOREACH (shared_ptr<Content> i, sel) {
/* These are the content types that could include subtitles */
shared_ptr<const FFmpegContent> fc = boost::dynamic_pointer_cast<const FFmpegContent> (i);
- shared_ptr<const TextSubtitleContent> sc = boost::dynamic_pointer_cast<const TextSubtitleContent> (i);
+ shared_ptr<const TextTextContent> sc = boost::dynamic_pointer_cast<const TextTextContent> (i);
shared_ptr<const DCPContent> dc = boost::dynamic_pointer_cast<const DCPContent> (i);
- shared_ptr<const DCPSubtitleContent> dsc = boost::dynamic_pointer_cast<const DCPSubtitleContent> (i);
+ shared_ptr<const DCPTextContent> dsc = boost::dynamic_pointer_cast<const DCPTextContent> (i);
if (fc) {
if (fc->subtitle) {
++ffmpeg_subs;
@@ -383,15 +383,15 @@ void
SubtitlePanel::content_selection_changed ()
{
film_content_changed (FFmpegContentProperty::SUBTITLE_STREAMS);
- film_content_changed (SubtitleContentProperty::USE);
- film_content_changed (SubtitleContentProperty::BURN);
- film_content_changed (SubtitleContentProperty::X_OFFSET);
- film_content_changed (SubtitleContentProperty::Y_OFFSET);
- film_content_changed (SubtitleContentProperty::X_SCALE);
- film_content_changed (SubtitleContentProperty::Y_SCALE);
- film_content_changed (SubtitleContentProperty::LINE_SPACING);
- film_content_changed (SubtitleContentProperty::LANGUAGE);
- film_content_changed (SubtitleContentProperty::FONTS);
+ film_content_changed (TextContentProperty::USE);
+ film_content_changed (TextContentProperty::BURN);
+ film_content_changed (TextContentProperty::X_OFFSET);
+ film_content_changed (TextContentProperty::Y_OFFSET);
+ film_content_changed (TextContentProperty::X_SCALE);
+ film_content_changed (TextContentProperty::Y_SCALE);
+ film_content_changed (TextContentProperty::LINE_SPACING);
+ film_content_changed (TextContentProperty::LANGUAGE);
+ film_content_changed (TextContentProperty::FONTS);
film_content_changed (DCPContentProperty::REFERENCE_SUBTITLE);
}
diff --git a/src/wx/subtitle_view.cc b/src/wx/subtitle_view.cc
index cedf273d4..7efe10d0c 100644
--- a/src/wx/subtitle_view.cc
+++ b/src/wx/subtitle_view.cc
@@ -18,13 +18,13 @@
*/
-#include "lib/text_subtitle_decoder.h"
+#include "lib/text_text_decoder.h"
#include "lib/content_subtitle.h"
#include "lib/video_decoder.h"
#include "lib/audio_decoder.h"
#include "lib/film.h"
-#include "lib/text_subtitle_content.h"
#include "lib/config.h"
+#include "lib/text_text_content.h"
#include "subtitle_view.h"
#include "film_viewer.h"
#include "wx_util.h"
diff --git a/src/wx/timeline.cc b/src/wx/timeline.cc
index e96b474cf..d0a898b18 100644
--- a/src/wx/timeline.cc
+++ b/src/wx/timeline.cc
@@ -25,7 +25,7 @@
#include "timeline_labels_view.h"
#include "timeline_video_content_view.h"
#include "timeline_audio_content_view.h"
-#include "timeline_subtitle_content_view.h"
+#include "timeline_text_content_view.h"
#include "timeline_atmos_content_view.h"
#include "content_panel.h"
#include "wx_util.h"
@@ -34,7 +34,7 @@
#include "lib/image_content.h"
#include "lib/timer.h"
#include "lib/audio_content.h"
-#include "lib/subtitle_content.h"
+#include "lib/text_content.h"
#include "lib/video_content.h"
#include "lib/atmos_mxf_content.h"
#include <wx/graphics.h>
@@ -229,7 +229,7 @@ Timeline::recreate_views ()
}
if (i->subtitle) {
- _views.push_back (shared_ptr<TimelineView> (new TimelineSubtitleContentView (*this, i)));
+ _views.push_back (shared_ptr<TimelineView> (new TimelineTextContentView (*this, i)));
}
if (dynamic_pointer_cast<AtmosMXFContent> (i)) {
@@ -375,7 +375,7 @@ Timeline::assign_tracks ()
/* Subtitle */
- int const subtitle_tracks = place<TimelineSubtitleContentView> (_views, _tracks);
+ int const subtitle_tracks = place<TimelineTextContentView> (_views, _tracks);
/* Atmos */
diff --git a/src/wx/timeline_subtitle_content_view.cc b/src/wx/timeline_text_content_view.cc
index f5c78525e..b4820bfea 100644
--- a/src/wx/timeline_subtitle_content_view.cc
+++ b/src/wx/timeline_text_content_view.cc
@@ -18,20 +18,20 @@
*/
-#include "timeline_subtitle_content_view.h"
-#include "lib/subtitle_content.h"
+#include "timeline_text_content_view.h"
+#include "lib/text_content.h"
#include "lib/content.h"
using boost::shared_ptr;
-TimelineSubtitleContentView::TimelineSubtitleContentView (Timeline& tl, shared_ptr<Content> c)
+TimelineTextContentView::TimelineTextContentView (Timeline& tl, shared_ptr<Content> c)
: TimelineContentView (tl, c)
{
}
wxColour
-TimelineSubtitleContentView::background_colour () const
+TimelineTextContentView::background_colour () const
{
if (!active ()) {
return wxColour (210, 210, 210, 128);
@@ -41,7 +41,7 @@ TimelineSubtitleContentView::background_colour () const
}
wxColour
-TimelineSubtitleContentView::foreground_colour () const
+TimelineTextContentView::foreground_colour () const
{
if (!active ()) {
return wxColour (180, 180, 180, 128);
@@ -51,7 +51,7 @@ TimelineSubtitleContentView::foreground_colour () const
}
bool
-TimelineSubtitleContentView::active () const
+TimelineTextContentView::active () const
{
shared_ptr<Content> c = _content.lock ();
DCPOMATIC_ASSERT (c);
diff --git a/src/wx/timing_panel.cc b/src/wx/timing_panel.cc
index 4006c5d3e..315ead524 100644
--- a/src/wx/timing_panel.cc
+++ b/src/wx/timing_panel.cc
@@ -26,10 +26,10 @@
#include "move_to_dialog.h"
#include "lib/content.h"
#include "lib/image_content.h"
-#include "lib/subtitle_content.h"
-#include "lib/dcp_subtitle_content.h"
+#include "lib/text_content.h"
+#include "lib/dcp_text_content.h"
#include "lib/audio_content.h"
-#include "lib/text_subtitle_content.h"
+#include "lib/text_text_content.h"
#include "lib/video_content.h"
#include <dcp/locale_convert.h>
#include <boost/foreach.hpp>
diff --git a/src/wx/wscript b/src/wx/wscript
index b5210bace..d5adafebe 100644
--- a/src/wx/wscript
+++ b/src/wx/wscript
@@ -109,7 +109,7 @@ sources = """
timeline_dialog.cc
timeline_audio_content_view.cc
timeline_labels_view.cc
- timeline_subtitle_content_view.cc
+ timeline_text_content_view.cc
timeline_reels_view.cc
timeline_time_axis_view.cc
timeline_video_content_view.cc
diff --git a/src/wx/timeline_subtitle_content_view.h b/src/wx/timeline_text_content_view.h
index a7a15f923..540a90607 100644
--- a/src/wx/timeline_subtitle_content_view.h
+++ b/src/wx/timeline_text_content_view.h
@@ -20,15 +20,15 @@
#include "timeline_content_view.h"
-class SubtitleContent;
+class TextContent;
-/** @class TimelineSubtitleContentView
- * @brief Timeline view for SubtitleContent.
+/** @class TimelineTextContentView
+ * @brief Timeline view for TextContent.
*/
-class TimelineSubtitleContentView : public TimelineContentView
+class TimelineTextContentView : public TimelineContentView
{
public:
- TimelineSubtitleContentView (Timeline& tl, boost::shared_ptr<Content> c);
+ TimelineTextContentView (Timeline& tl, boost::shared_ptr<Content> c);
private:
bool active () const;